@@ -23,6 +23,7 @@ from obsplus.constants import (
     READ_HDF5_KWARGS,
 )
 from obsplus.exceptions import UnsupportedKeyword
+from obsplus.utils.geodetics import map_longitudes
 from obsplus.utils.misc import READ_DICT, _get_path
 from obsplus.utils.mseed import summarize_mseed
 from obsplus.utils.time import to_datetime64, _dict_times_to_ns
@@ -40,7 +41,7 @@ STATION_EXT = ".xml"
 
 
 def _get_time_values(time1, time2=None):
-    """ get the time values from a UTCDateTime object or two """
+    """get the time values from a UTCDateTime object or two"""
     tvals = "year month day hour minute second microsecond".split()
     utc1 = time1
     split = re.split("-|:|T|[.]", str(utc1).replace("Z", ""))
@@ -152,7 +153,7 @@ def _natify_paths(series: pd.Series) -> pd.Series:
 
 
 class _IndexCache:
-    """ A simple class for caching indexes """
+    """A simple class for caching indexes"""
 
     def __init__(self, bank, cache_size=5):
         self.max_size = cache_size
@@ -164,7 +165,7 @@ class _IndexCache:
         # self.next_index = itertools.cycle(self.cache.index)
 
     def __call__(self, starttime, endtime, buffer, **kwargs):
-        """ get start and end times, perform in kernel lookup """
+        """get start and end times, perform in kernel lookup"""
         starttime, endtime = self._get_times(starttime, endtime)
         self._validate_kwargs(kwargs)
         # find out if the query falls within one cached times
@@ -213,7 +214,7 @@ class _IndexCache:
             raise UnsupportedKeyword(msg)
 
     def _set_cache(self, index, starttime, endtime, kwargs):
-        """Cache the current index """
+        """Cache the current index"""
         ser = pd.Series(
             {
                 "t1": starttime,
@@ -225,13 +226,13 @@ class _IndexCache:
         self.cache.loc[self._get_next_index()] = ser
 
     def _kwargs_to_str(self, kwargs):
-        """ convert kwargs to a string """
+        """convert kwargs to a string"""
         keys = sorted(list(kwargs.keys()))
         ou = str([(item, kwargs[item]) for item in keys])
         return ou
 
     def _get_index(self, where, fail_counts=0, **kwargs):
-        """ read the hdf5 file """
+        """read the hdf5 file"""
         try:
             return pd.read_hdf(
                 self.bank.index_path, self.bank._index_node, where=where, **kwargs
@@ -246,7 +247,7 @@ class _IndexCache:
             return self._get_index(where, fail_counts=fail_counts + 1, **kwargs)
 
     def clear_cache(self):
-        """ removes all cached dataframes. """
+        """removes all cached dataframes."""
         self.cache = pd.DataFrame(
             index=range(self.max_size), columns="t1 t2 kwargs cindex".split()
         )
@@ -319,10 +320,10 @@ def _str_of_params(value):
 
 
 def _make_wheres(queries):
-    """ Create the where queries, join with AND clauses """
+    """Create the where queries, join with AND clauses"""
 
     def _rename_keys(kwargs):
-        """ re-word some keys to make automatic sql generation easier"""
+        """re-word some keys to make automatic sql generation easier"""
         if "eventid" in kwargs:
             kwargs["event_id"] = kwargs.pop("eventid")
         if "event_id" in kwargs:
@@ -336,14 +337,31 @@ def _make_wheres(queries):
         return kwargs
 
     def _handle_nat(kwargs):
-        """ add a mintime that will exclude NaT values if endtime is used """
+        """add a mintime that will exclude NaT values if endtime is used"""
         if "maxtime" in kwargs and "mintime" not in kwargs:
             kwargs["mintime"] = SMALLDT64.astype(np.int64) + 1
         return kwargs
 
+    def _handle_dateline_transversal(kwargs, out):
+        """Check if dateline should be transversed by query."""
+        # if longitudes aren't being used bail out
+        if not {"minlongitude", "maxlongitude"}.issubset(set(kwargs)):
+            return kwargs, out
+        # if dateline is not to be transversed by query bail out
+        long_array = np.array([kwargs["minlongitude"], kwargs["maxlongitude"]])
+        minlong, maxlong = map_longitudes(long_array)
+        if not minlong > maxlong:
+            return kwargs, out
+        # remove min/max long from query dict and reform to two queries.
+        kwargs.pop("minlongitude"), kwargs.pop("maxlongitude")
+        cond = f"(( longitude > {minlong}) OR ( longitude < {maxlong})) "
+        out.append(cond)
+        return kwargs, out
+
     def _build_query(kwargs):
-        """ iterate each key/value and build query """
+        """iterate each key/value and build query"""
         out = []
+        kwargs, out = _handle_dateline_transversal(kwargs, out)
         for key, val in kwargs.items():
             # deal with simple min/max
             if key.startswith("min"):
@@ -354,7 +372,7 @@ def _make_wheres(queries):
             elif isinstance(val, Sequence):
                 if isinstance(val, str):
                     val = [val]
-                tup = str(tuple(val)).replace(",)", ")")  # no trailing coma
+                tup = str(tuple(val)).replace(",)", ")")  # no trailing comma
                 out.append(f"{key} IN {tup}")
             else:
                 out.append(f"{key} = {val}")
@@ -367,7 +385,7 @@ def _make_wheres(queries):
 
 
 def _make_sql_command(cmd, table_name, columns=None, **kwargs) -> str:
-    """ build a sql command """
+    """build a sql command"""
     # get columns
     if columns:
         col = [columns] if isinstance(columns, str) else columns
@@ -408,13 +426,13 @@ def _read_table(table_name, con, columns=None, **kwargs) -> pd.DataFrame:
 
 
 def _get_tables(con):
-    """ Return a list of table in sqlite database """
+    """Return a list of table in sqlite database"""
     out = con.execute("SELECT name FROM sqlite_master WHERE type='table';")
     return set(out)
 
 
 def _drop_rows(table_name, con, columns=None, **kwargs):
-    """ Drop indicies in table """
+    """Drop indicies in table"""
     sql = _make_sql_command("delete", table_name, columns=columns, **kwargs)
     con.execute(sql)
 
